summaryrefslogtreecommitdiffstats
path: root/components/navigation_interception/intercept_navigation_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'components/navigation_interception/intercept_navigation_delegate.h')
-rw-r--r--components/navigation_interception/intercept_navigation_delegate.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/components/navigation_interception/intercept_navigation_delegate.h b/components/navigation_interception/intercept_navigation_delegate.h
index d84969f..57858fd 100644
--- a/components/navigation_interception/intercept_navigation_delegate.h
+++ b/components/navigation_interception/intercept_navigation_delegate.h
@@ -12,7 +12,8 @@
class GURL;
namespace content {
-class ResourceThrottle;
+class NavigationHandle;
+class NavigationThrottle;
class WebContents;
}
@@ -32,9 +33,8 @@ class NavigationParams;
// 1) the Java-side interface implementation must be associated (via the
// Associate method) with a WebContents for which URLRequests are to be
// intercepted,
// 2) the ResourceThrottle obtained via CreateThrottleFor must be associated
// with the URLRequests in the ResourceDispatcherHostDelegate
// implementation.
class InterceptNavigationDelegate : public base::SupportsUserData::Data {
public:
InterceptNavigationDelegate(JNIEnv* env, jobject jdelegate);
@@ -50,10 +50,10 @@ class InterceptNavigationDelegate : public base::SupportsUserData::Data {
// can be null.
static InterceptNavigationDelegate* Get(content::WebContents* web_contents);
- // Creates a InterceptNavigationResourceThrottle that will direct all
- // callbacks to the InterceptNavigationDelegate.
- static content::ResourceThrottle* CreateThrottleFor(
- net::URLRequest* request);
+ // Creates a InterceptNavigationThrottle that will direct all callbacks to
+ // the InterceptNavigationDelegate.
+ static scoped_ptr<content::NavigationThrottle> CreateThrottleFor(
+ content::NavigationHandle* handle);
// Updates information to determine whether to have user gesture carryover or
// not.
@@ -32,9 +33,8 @@ class NavigationParams;
// Associate method) with a WebContents for which URLRequests are to be
// intercepted,
-// 2) the ResourceThrottle obtained via CreateThrottleFor must be associated
-// with the URLRequests in the ResourceDispatcherHostDelegate
-// implementation.
+// 2) the NavigationThrottle obtained via CreateThrottleFor must be associated
+// with the NavigationHandle in the ContentBrowserClient implementation.
class InterceptNavigationDelegate : public base::SupportsUserData::Data {
public: